pub enum UpcAParseError {
InputTooLarge {
found: u64,
},
ParseIntError(ParseIntError),
ChecksumFailed {
found: u8,
},
}Expand description
Error that can occur during parsing a UPC-A code.
This enum represents all the possible errors that can occur when validating or parsing a UPC-A from various input formats.
Variants
InputTooLarge
The input is too large to be a valid UPC-A code.
ParseIntError(ParseIntError)
The input string is not a valid integer.
ChecksumFailed
The checksum digit is invalid.